PaginationModel class

Constructors

PaginationModel({int limit = 10, int currentPage = 1, int totalEntries = 0, int totalPages = 0, bool hasPrevPage = false, bool hasNextPage = false})
PaginationModel.fromJson(Map<String, dynamic> json)
factory

Properties

currentPage int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hasNextPage bool
getter/setter pair
hasPrevPage bool
getter/setter pair
limit int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalEntries int
getter/setter pair
totalPages int
getter/setter pair

Methods

copyWith({int? limit, int? currentPage}) PaginationModel
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited