ResponseModel<T> class
Constructors
-
ResponseModel({required int statusCode, String? message, dynamic dataResponse, PaginationModel? meta, List<
Errors> ? errors}) -
ResponseModel.fromJson(Map<
String, dynamic> json, {T fromJson(Map<String, dynamic> )?}) -
factory
Properties
- dataAttribute ↔ dynamic
-
getter/setter pair
- dataResponse ↔ dynamic
-
getter/setter pair
-
errors
↔ List<
Errors> -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- message ↔ String?
-
getter/setter pair
- meta ↔ PaginationModel?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statusCode ↔ int
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited