AppLog class

Constructors

AppLog()
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showLog bool
getter/setter pair

Methods

formatException({required String errorFunction, required dynamic error}) String
initial({bool? showLog}) → dynamic
log([String tag = tag, dynamic msg]) → dynamic
logJson([String tag = tag, dynamic msg]) → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

tag → const String